Generate TypedDict Automatically
================================

実用的ではない、ほぼ自分用

.. image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :target: http://opensource.org/licenses/MIT
.. image:: https://badge.fury.io/py/typingdict.svg
    :target: https://badge.fury.io/py/typingdict

.. image:: https://raw.githubusercontent.com/am230/typingdict/master/images/screenshot.png

Usage
-----

.. code:: bash

    py -m typingdict .\input.json > output.py
